@@ -8,7 +8,6 @@ import json
 import getpass
 from scale.utils import get_job_body, convert_source_file_to_user_command
 from scale.receive_log import get_log_from_container
-from builtins import input
 
 
 class Client(object):
@@ -34,7 +33,7 @@ class Client(object):
     def _config_check(self):
         for k in self.conf:
             if not self.conf[k]:
-                print("need to login to create job. ex) scale login")
+                print("need to login to create job\nex) scalecli login")
                 sys.exit(1)
 
     def config(self, *args):
@@ -46,10 +45,13 @@ class Client(object):
     def login(self):
         if not self.conf["url"]:
             print(
-                "Please set paas_url using cli ex: scale config set url http://0.0.0.0:13202"
+                "Please set paas_url using cli\nex) scalecli config set url http://0.0.0.0:13202"
             )
             sys.exit(1)
-        paas_id = input("Enter paas id: ")
+        if sys.version_info[0] == 2:
+            paas_id = raw_input("Enter paas id: ")
+        else:
+            paas_id = input("Enter paas id: ")
         paas_paassword = getpass.getpass("Enter paas password: ")
         r = requests.post(
             "{}/api/auth/login".format(self.conf["url"]),
